###################################################################
##
##  This add-on to 
##
##
DeclareFilter( "IsGraphicIdealLattice" );
DeclareOperation( "GraphicIdealLattice", [IsNearRing, IsString] );

